@@ -1,12 +1,12 @@
 test_that("Check 3d scatter box", {
   sb1 <- plot_3d_scatterbox(data_2w_Tdeath, #plotted with grafify
-                            Genotype, 
-                            PI, 
+                            Genotype,
+                            PI,
                             Time,
                             TextXAngle = 45,
                             ColPal = "muted",
-                            ColRev = T)       
-  
+                            ColRev = T)
+
   sb2 <- ggplot(data = data_2w_Tdeath,  #with ggplot2
                 aes(x = Genotype,
                     y = PI,
@@ -30,27 +30,27 @@ test_that("Check 3d scatter box", {
                  fun.args = list(mult = 1),
                  position = position_dodge(width = 0.8))+
     scale_shape_manual(values = 0:25)+
-    labs(x = "Genotype", 
-         y = "PI", 
+    labs(x = "Genotype",
+         y = "PI",
          shape = "Time")+
     theme_classic(base_size = 20)+
     theme(strip.background = element_blank())+
     guides(x = guide_axis(angle = 0))+
     scale_fill_grafify(palette = "all_grafify",
                        reverse = FALSE)
-  
+
   #test key layers and data file
   expect_equal(sb1$data, sb2$data)
   expect_s3_class(sb1, "ggplot")
   expect_equal(sb1$theme$text$size, 20)
   #match aesthetics in labels
-  expect_match(as.character(rlang::quo_get_expr(sb1$labels$x)), 
+  expect_match(as.character(rlang::quo_get_expr(sb1$labels$x)),
                "Genotype")
-  expect_match(sb1$labels$y, 
-               "PI")
-  #expect_match(as.character(rlang::quo_get_expr(sb1$labels$shape)), 
+  #expect_match(sb1$labels$y,
+  #             "PI")
+  #expect_match(as.character(rlang::quo_get_expr(sb1$labels$shape)),
   #             "Time")
-  #expect_match(as.character(rlang::quo_get_expr(sb1$labels$fill)), 
+  #expect_match(as.character(rlang::quo_get_expr(sb1$labels$fill)),
   #             "Genotype")
   #check guide titles from 3.2.1 onwards
   #expect_match(sb1$labels$x, "Genotype")
@@ -58,4 +58,9 @@ test_that("Check 3d scatter box", {
   #expect_match(sb1$labels$fill, "Genotype")
   #check text angle is passed on
   #expect_equal(get_guide_angle(sb1, "x"), 45)
+  ## new 13/06/2025 tests PASS
+  labels <- get_labs(sb2)
+  expect_match(labels$y, "PI")
+  #expect_true(inherits(sb2$labels, c("ggplot2::labels", "labels")))
+  ##
 })
